==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/vi-VN/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Danh mục tài sản',
    'category_name'  					=> 'Tên hạng mục',
    'checkin_email'                     => 'Gửi email đến người dùng khi checkin/checkout.',
    'checkin_email_notification'        => 'Người dùng này sẽ được gửi email khi checkin/checkout.',
    'clone'                             => 'Nhân đôi Danh mục',
    'create'  							=> 'Tạo hạng mục',
    'edit'                              => 'Chính sửa hạng mục',
    'email_will_be_sent_due_to_global_eula' => 'Một email sẽ được gửi đến người dùng vì thỏa thuận người dùng cuối toàn cầu (global EULA) đang được sử dụng.',
    'email_will_be_sent_due_to_category_eula' => 'Một email sẽ được gửi đến người dùng vì thỏa thuận người dùng cuối (EULA) được đặt cho danh mục này.',
    'eula_text'							=> 'Danh mục EULA',
    'eula_text_help'					=> 'Đây là trường cho phép bạn điều chỉnh EULA cho những loại tài sản riêng biệt. Nếu bạn chỉ có một EULA cho tất cả tài sản, bạn có thể nhấn chọn vào ô bên dưới để sử dụng như là giá trị mặc định.',
    'name'                              => 'tên danh mục',
    'require_acceptance'				=> 'Yêu cầu người dùng xác nhận nhận tài sản trong hạng mục này.',
    'required_acceptance'				=> 'Người dùng sẽ nhận được email có chứa đường dẫn để xác nhận chấp nhận tài sản này.',
    'required_eula'						=> 'Đây là người dùng đã được gửi một email bản sao của EULA',
    'no_default_eula'					=> 'Không tìm thấy giá trị EULA mặc định. Thêm vào một giá trị trong Cài đặt.',
    'update'  							=> 'Cập nhật hạng mục',
    'use_default_eula'					=> 'Sử dụng <a href="#" data-toggle="modal" data-target="#eulaModal">giá trị EULA mặc đinh</a> để thay vào.',
    'use_default_eula_disabled'			=> '<del>Sử dụng giá trị EULA mặc định để thay thế.</del> No primary default EULA is set. Please add one in Settings.',
    'use_default_eula_column'			=> 'Sử dụng EULA mặc định',

);

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/vi-VN/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Danh mục tài sản',
    'category_name'  					=> 'Tên hạng mục',
    'checkin_email'                     => 'Gửi email đến người dùng khi checkin/checkout.',
    'email_to_initiator'                => 'Send email to you when user accepts or declines checkout.',
    'checkin_email_notification'        => 'Người dùng này sẽ được gửi email khi checkin/checkout.',
    'clone'                             => 'Nhân đôi Danh mục',
    'create'  							=> 'Tạo hạng mục',
    'edit'                              => 'Chính sửa hạng mục',
    'email_will_be_sent_due_to_global_eula' => 'Một email sẽ được gửi đến người dùng vì thỏa thuận người dùng cuối toàn cầu (global EULA) đang được sử dụng.',
    'email_will_be_sent_due_to_category_eula' => 'Một email sẽ được gửi đến người dùng vì thỏa thuận người dùng cuối (EULA) được đặt cho danh mục này.',
    'eula_text'							=> 'Danh mục EULA',
    'eula_text_help'					=> 'Đây là trường cho phép bạn điều chỉnh EULA cho những loại tài sản riêng biệt. Nếu bạn chỉ có một EULA cho tất cả tài sản, bạn có thể nhấn chọn vào ô bên dưới để sử dụng như là giá trị mặc định.',
    'name'                              => 'tên danh mục',
    'require_acceptance'				=> 'Yêu cầu người dùng xác nhận nhận tài sản trong hạng mục này.',
    'required_acceptance'				=> 'Người dùng sẽ nhận được email có chứa đường dẫn để xác nhận chấp nhận tài sản này.',
    'required_eula'						=> 'Đây là người dùng đã được gửi một email bản sao của EULA',
    'no_default_eula'					=> 'Không tìm thấy giá trị EULA mặc định. Thêm vào một giá trị trong Cài đặt.',
    'update'  							=> 'Cập nhật hạng mục',
    'use_default_eula'					=> 'Sử dụng <a href="#" data-toggle="modal" data-target="#eulaModal">giá trị EULA mặc đinh</a> để thay vào.',
    'use_default_eula_disabled'			=> '<del>Sử dụng giá trị EULA mặc định để thay thế.</del> No primary default EULA is set. Please add one in Settings.',
    'use_default_eula_column'			=> 'Sử dụng EULA mặc định',
    'import_require_acceptance'         => 'Require Acceptance',
    'import_checkin_email'              => 'Send Checkin Email',
    'import_eula_text'                  => 'EULA text',
    'import_category_type'              => 'Kiểu danh mục',

);
